@@ -8,7 +8,7 @@ var languageNames = {
 "bn-IN": "Bengáli (India)",
 "bo": "Tibeti",
 "bs": "Bosnyák",
-"ca": "Catalan",
+"ca": "Katalán",
 "ca-valencia": "Valenciai katalán",
 "cs": "Cseh",
 "da": "Dán",
@@ -48,20 +48,20 @@ var languageNames = {
 "pl": "Lengyel",
 "pt": "Portugál",
 "pt-BR": "Brazíliai portugál",
-"ro": "Romanian",
-"ru": "Russian",
-"si": "Sinhala",
+"ro": "Román",
+"ru": "Orosz",
+"si": "Szingaléz",
 "sid": "Szidamo",
-"sk": "Slovak",
-"sl": "Slovenian",
-"sq": "Albanian",
-"sv": "Swedish",
+"sk": "Szlovák",
+"sl": "Szlovén",
+"sq": "Albán",
+"sv": "Svéd",
 "ta": "Tamil",
-"tg": "Tajik",
-"tr": "Turkish",
-"ug": "Uyghur",
-"uk": "Ukrainian",
-"vi": "Vietnamese",
-"zh-CN": "Chinese (Simplified)",
-"zh-TW": "Chinese (Traditional)",
+"tg": "Tádzsik",
+"tr": "Török",
+"ug": "Ujgur",
+"uk": "Ukrán",
+"vi": "Vietnami",
+"zh-CN": "Kínai (egyszerűsített)",
+"zh-TW": "Kínai (hagyományos)",
 };
